@@ -30,6 +30,7 @@ use Exception;
 use Illuminate\Database\QueryException;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Str;
+use LibreNMS\Data\Store\Rrd;
 use LibreNMS\DB\Eloquent;
 use LibreNMS\Util\Debug;
 use Log;
@@ -457,6 +458,10 @@ class Config
             }
         }
 
+        if (! self::has('rrdtool_version')) {
+            self::persist('rrdtool_version', Rrd::version());
+        }
+
         self::populateTime();
 
         // populate legacy DB credentials, just in case something external uses them.  Maybe remove this later
