@@ -68,8 +68,12 @@ class Windows extends \LibreNMS\OS
     private function getClientVersion($build, $version)
     {
         $default = $build > 10000 ? '10 (NT 6.3)' : null;
+        $default = $build > 22000 ? '11 Insider (NT 6.3)' : null;
 
         $builds = [
+            '22000' => '11 2110 (NT 6.3)',
+            '19043' => '10 21H1 (NT 6.3)',
+            '19042' => '10 20H2 (NT 6.3)',
             '19041' => '10 2004 (NT 6.3)',
             '18363' => '10 1909 (NT 6.3)',
             '18362' => '10 1903 (NT 6.3)',
