@@ -41,22 +41,22 @@ class GitHub
     protected $pull_requests = [];
     protected $changelog = [
         'feature' => [],
-        'enhancement' => [],
         'breaking change' => [],
         'security' => [],
         'device' => [],
         'webui' => [],
-        'authentication' => [],
+        'alerting' => [],
         'graphs' => [],
         'snmp traps' => [],
         'applications' => [],
-        'api' => [],
-        'alerting' => [],
         'billing' => [],
+        'api' => [],
+        'settings' => [],
         'discovery' => [],
         'polling' => [],
         'rancid' => [],
         'oxidized' => [],
+        'authentication' => [],
         'bug' => [],
         'refactor' => [],
         'cleanup' => [],
