@@ -52,6 +52,7 @@ use App\Models\Vrf;
 use App\Models\WirelessSensor;
 use Illuminate\Http\Request;
 use LibreNMS\Config;
+use LibreNMS\Data\Store\Rrd;
 use LibreNMS\DB\Eloquent;
 use LibreNMS\Util\Version;
 
@@ -67,29 +68,27 @@ class AboutController extends Controller
             'callback_uuid'   => $callback_status ? Callback::get('uuid') : null,
 
             'db_schema' => vsprintf('%s (%s)', $version->database()),
-            'git_log'   => $version->gitChangelog(),
-            'git_date'  => $version->gitDate(),
+            'git_log' => $version->gitChangelog(),
+            'git_date' => $version->gitDate(),
             'project_name' => Config::get('project_name'),
 
-            'version_local'     => $version->local(),
-            'version_mysql'     => Eloquent::version(),
-            'version_php'       => phpversion(),
-            'version_laravel'   => App::VERSION(),
-            'version_python'    => Version::python(),
+            'version_local' => $version->local(),
+            'version_mysql' => Eloquent::version(),
+            'version_php' => phpversion(),
+            'version_laravel' => App::VERSION(),
+            'version_python' => Version::python(),
             'version_webserver' => $request->server('SERVER_SOFTWARE'),
-            'version_rrdtool'   => str_replace('1.7.01.7.0', '1.7.0', implode(' ', array_slice(explode(' ', shell_exec(
-                Config::get('rrdtool', 'rrdtool') . ' --version | head -n1'
-            )), 1, 1))),
-            'version_netsnmp'   => str_replace('version: ', '', rtrim(shell_exec(Config::get('snmpget', 'snmpget') . ' -V 2>&1'))),
+            'version_rrdtool' => Rrd::version(),
+            'version_netsnmp' => str_replace('version: ', '', rtrim(shell_exec(Config::get('snmpget', 'snmpget') . ' -V 2>&1'))),
 
-            'stat_apps'       => Application::count(),
-            'stat_devices'    => Device::count(),
-            'stat_diskio'     => DiskIo::count(),
-            'stat_entphys'    => EntPhysical::count(),
-            'stat_events'     => Eventlog::count(),
-            'stat_hrdev'      => HrDevice::count(),
-            'stat_ipv4_addy'  => Ipv4Address::count(),
-            'stat_ipv4_nets'  => Ipv4Network::count(),
+            'stat_apps' => Application::count(),
+            'stat_devices' => Device::count(),
+            'stat_diskio' => DiskIo::count(),
+            'stat_entphys' => EntPhysical::count(),
+            'stat_events' => Eventlog::count(),
+            'stat_hrdev' => HrDevice::count(),
+            'stat_ipv4_addy' => Ipv4Address::count(),
+            'stat_ipv4_nets' => Ipv4Network::count(),
             'stat_ipv6_addy'  => Ipv6Address::count(),
             'stat_ipv6_nets'  => Ipv6Network::count(),
             'stat_memory'     => Mempool::count(),
