@@ -25,6 +25,10 @@ if ($device['os'] == 'openbsd') {
     include 'includes/discovery/sensors/openbsd.inc.php';
 }
 
+if ($device['os'] == 'linux') {
+    include 'includes/discovery/sensors/rpigpiomonitor.inc.php';
+}
+
 if (strstr($device['hardware'], 'Dell')) {
     include 'includes/discovery/sensors/fanspeed/dell.inc.php';
     include 'includes/discovery/sensors/power/dell.inc.php';
@@ -80,7 +84,7 @@ $run_sensors = [
 // filter submodules
 $run_sensors = array_intersect($run_sensors, Config::get('discovery_submodules.sensors', $run_sensors));
 
-sensors($run_sensors, $device, $valid, $pre_cache);
+sensors($run_sensors, $os, $valid, $pre_cache);
 unset(
     $pre_cache,
     $run_sensors,
