@@ -22,6 +22,7 @@ use App\Models\PortGroup;
 use App\Models\PortsFdb;
 use App\Models\Sensor;
 use App\Models\ServiceTemplate;
+use App\Models\UserPref;
 use Illuminate\Database\Eloquent\Builder;
 use Illuminate\Routing\Router;
 use Illuminate\Support\Arr;
@@ -419,7 +420,9 @@ function add_device(Illuminate\Http\Request $request)
         return api_error(500, $e->getMessage());
     }
 
-    return api_success_noresult(201, "Device $hostname ($device_id) has been added successfully");
+    $device = device_by_id_cache($device_id);
+
+    return api_success([$device], 'devices', $response);
 }
 
 function del_device(Illuminate\Http\Request $request)
@@ -453,6 +456,48 @@ function del_device(Illuminate\Http\Request $request)
     return api_success([$device], 'devices', $response);
 }
 
+function maintenance_device(Illuminate\Http\Request $request)
+{
+    if (empty($request->json())) {
+        return api_error(400, 'No information has been provided to set this device into maintenance');
+    }
+
+    // This will add a device using the data passed encoded with json
+    $hostname = $request->route('hostname');
+
+    // use hostname as device_id if it's all digits
+    $device = ctype_digit($hostname) ? DeviceCache::get($hostname) : DeviceCache::getByHostname($hostname);
+
+    if (! $device) {
+        return api_error(404, "Device $hostname does not exist");
+    }
+
+    $notes = $request->json('notes');
+    $alert_schedule = new \App\Models\AlertSchedule([
+        'title' => $device->displayName(),
+        'notes' => $notes,
+        'recurring' => 0,
+        'start' => date('Y-m-d H:i:s'),
+    ]);
+
+    $duration = $request->json('duration');
+    if (Str::contains($duration, ':')) {
+        [$duration_hour, $duration_min] = explode(':', $duration);
+        $alert_schedule->end = \Carbon\Carbon::now()
+            ->addHours($duration_hour)->addMinutes($duration_min)
+            ->format('Y-m-d H:i:00');
+    }
+
+    $device->alertSchedules()->save($alert_schedule);
+
+    if ($notes && UserPref::getPref(Auth::user(), 'add_schedule_note_to_device')) {
+        $device->notes .= (empty($device->notes) ? '' : PHP_EOL) . date('Y-m-d H:i') . ' Alerts delayed: ' . $notes;
+        $device->save();
+    }
+
+    return api_success_noresult(201, "Device {$device->hostname} ({$device->device_id}) moved into maintenance mode" . ($duration ? " for {$duration}h" : ''));
+}
+
 function device_availability(Illuminate\Http\Request $request)
 {
     // return availability per device
@@ -1019,15 +1064,23 @@ function get_port_info(Illuminate\Http\Request $request)
 
 function search_ports(Illuminate\Http\Request $request)
 {
+    $field = $request->route('field');
     $search = $request->route('search');
-    $value = "%$search%";
-    $ports = Port::hasAccess(Auth::user())
-         ->select(['device_id', 'port_id', 'ifIndex', 'ifName'])
-         ->where('ifAlias', 'like', $value)
-         ->orWhere('ifDescr', 'like', $value)
-         ->orWhere('ifName', 'like', $value)
-         ->orderBy('ifName')
-         ->get();
+
+    $query = Port::hasAccess(Auth::user())
+         ->select(['device_id', 'port_id', 'ifIndex', 'ifName']);
+
+    if (isset($search)) {
+        $query->where($field, 'like', "%$search%");
+    } else {
+        $value = "%$field%";
+        $query->where('ifAlias', 'like', $value)
+            ->orWhere('ifDescr', 'like', $value)
+            ->orWhere('ifName', 'like', $value);
+    }
+
+    $ports = $query->orderBy('ifName')
+                   ->get();
 
     if ($ports->isEmpty()) {
         return api_error(404, 'No ports found');
@@ -1924,6 +1977,76 @@ function get_port_groups(Illuminate\Http\Request $request)
     return api_success($groups->makeHidden('pivot')->toArray(), 'groups', 'Found ' . $groups->count() . ' port groups');
 }
 
+function get_ports_by_group(Illuminate\Http\Request $request)
+{
+    $name = $request->route('name');
+    if (! $name) {
+        return api_error(400, 'No port group name provided');
+    }
+
+    $port_group = ctype_digit($name) ? PortGroup::find($name) : PortGroup::where('name', $name)->first();
+
+    if (empty($port_group)) {
+        return api_error(404, 'Port group not found');
+    }
+
+    $ports = $port_group->ports()->get($request->get('full') ? ['*'] : ['ports.port_id']);
+
+    if ($ports->isEmpty()) {
+        return api_error(404, 'No ports found in group ' . $name);
+    }
+
+    return api_success($ports->makeHidden('pivot')->toArray(), 'ports');
+}
+
+function assign_port_group(Illuminate\Http\Request $request)
+{
+    $port_group_id = $request->route('port_group_id');
+    $data = json_decode($request->getContent(), true);
+    $port_id_list = $data['port_ids'];
+
+    if (json_last_error() || ! is_array($data)) {
+        return api_error(400, "We couldn't parse the provided json. " . json_last_error_msg());
+    }
+
+    if (! isset($port_id_list)) {
+        return api_error(400, "Missing data field 'port_ids' " . json_last_error_msg());
+    }
+
+    $port_group = PortGroup::find($port_group_id);
+    if (! isset($port_group)) {
+        return api_error(404, 'Port Group ID ' . $port_group_id . ' not found');
+    }
+
+    $port_group->ports()->attach($port_id_list);
+
+    return api_success(200, 'Port Ids ' . implode(', ', $port_id_list) . ' have been added to Port Group Id ' . $port_group_id);
+}
+
+function remove_port_group(Illuminate\Http\Request $request)
+{
+    $port_group_id = $request->route('port_group_id');
+    $data = json_decode($request->getContent(), true);
+    $port_id_list = $data['port_ids'];
+
+    if (json_last_error() || ! is_array($data)) {
+        return api_error(400, "We couldn't parse the provided json. " . json_last_error_msg());
+    }
+
+    if (! isset($port_id_list)) {
+        return api_error(400, "Missing data field 'port_ids' " . json_last_error_msg());
+    }
+
+    $port_group = PortGroup::find($port_group_id);
+    if (! isset($port_group)) {
+        return api_error(404, 'Port Group ID ' . $port_group_id . ' not found');
+    }
+
+    $port_group->ports()->detach($port_id_list);
+
+    return api_success(200, 'Port Ids ' . implode(', ', $port_id_list) . ' have been removed from Port Group Id ' . $port_group_id);
+}
+
 function add_device_group(Illuminate\Http\Request $request)
 {
     $data = json_decode($request->getContent(), true);
@@ -1944,10 +2067,12 @@ function add_device_group(Illuminate\Http\Request $request)
         return api_error(422, $v->messages());
     }
 
-    // Only use the rules if they are able to be parsed by the QueryBuilder
-    $query = QueryBuilderParser::fromJson($data['rules'])->toSql();
-    if (empty($query)) {
-        return api_error(500, "We couldn't parse your rule");
+    if (! empty($data['rules'])) {
+        // Only use the rules if they are able to be parsed by the QueryBuilder
+        $query = QueryBuilderParser::fromJson($data['rules'])->toSql();
+        if (empty($query)) {
+            return api_error(500, "We couldn't parse your rule");
+        }
     }
 
     $deviceGroup = DeviceGroup::make(['name' => $data['name'], 'type' => $data['type'], 'desc' => $data['desc']]);
