@@ -13,7 +13,7 @@ header('Content-type: application/json');
 
 $status = 'error';
 $message = 'unknown error';
-$parameters = clean($_POST['search_in_conf_textbox']);
+$parameters = strip_tags($_POST['search_in_conf_textbox']);
 if (isset($parameters)) {
     $message = 'Queried';
     if ($output = search_oxidized_config($parameters)) {
@@ -22,9 +22,9 @@ if (isset($parameters)) {
 } else {
     $message = 'ERROR: Could not query';
 }
-echo display(json_encode([
+echo \LibreNMS\Util\Clean::html(json_encode([
     'status' => $status,
     'message' => $message,
     'search_in_conf_textbox' => $parameters,
     'output' => $output,
-], JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE));
+], JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE), []);
