@@ -8,7 +8,7 @@ $i = 0;
 $scale_min = 0;
 $nototal = 1;
 $unit_text = 'Query/s';
-$rrd_filename = rrd_name($device['hostname'], ['app', 'unbound-queries', $app['app_id']]);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'unbound-queries', $app['app_id']]);
 $array = [
     'type0',
     'A',
@@ -35,7 +35,7 @@ $rrd_list = [];
 
 Config::set('graph_colours.merged', array_merge(Config::get('graph_colours.greens'), Config::get('graph_colours.blues')));
 
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     foreach ($array as $ds) {
         $rrd_list[$i]['filename'] = $rrd_filename;
         $rrd_list[$i]['descr'] = strtoupper($ds);
