@@ -180,38 +180,35 @@ $max_repeaters = get_dev_attrib($device, 'snmp_max_repeaters');
 
 echo '<h3> SNMP Settings </h3>';
 
-// use Toastr to print normal (success) messages, similar to Device Settings
+// use PHP Flasher to print normal (success) messages, similar to Device Settings
 if (isset($update_message)) {
-    $toastr_options = [];
-
     if (is_array($update_message)) {
         foreach ($update_message as $message) {
-            Toastr::success($message, null, $toastr_options);
+            flash()->addSuccess($message);
         }
     }
 
     if (is_string($update_message)) {
-        Toastr::success($update_message, null, $toastr_options);
+        flash()->addSuccess($update_message);
     }
 
-    unset($message, $toastr_options, $update_message);
+    unset($message, $update_message);
 }
 
-// use Toastr:error to call attention to the problem; don't let it time out
+// use flash()->addError to call attention to the problem; don't let it time out
 if (isset($update_failed_message)) {
-    $toastr_options = [];
-    $toastr_options['closeButton'] = true;
-    $toastr_options['extendedTimeOut'] = 0;
-    $toastr_options['timeOut'] = 0;
-
     if (is_array($update_failed_message)) {
         foreach ($update_failed_message as $error) {
-            Toastr::error($error, null, $toastr_options);
+            flash()
+                ->option('timeout', 30000)
+                ->addError($error);
         }
     }
 
     if (is_string($update_failed_message)) {
-        Toastr::error($update_failed_message, null, $toastr_options);
+        flash()
+            ->option('timeout', 30000)
+            ->addError($update_failed_message);
     }
 
     unset($error, $update_failed_message);
@@ -301,7 +298,6 @@ foreach (get_port_assoc_modes() as $pam_id => $pam) {
     echo ">$pam</option>\n";
 }
 
-['sha2' => $snmpv3_sha2, 'aes256' => $snmpv3_aes256] = snmpv3_capabilities();
 echo "        </select>
       </div>
     </div>
@@ -357,19 +353,16 @@ echo "        </select>
     <div class='form-group'>
     <label for='authalgo' class='col-sm-2 control-label'>Auth Algorithm</label>
     <div class='col-sm-4'>
-    <select id='authalgo' name='authalgo' class='form-control'>
-    <option value='MD5'>MD5</option>
-    <option value='SHA' " . ($device['authalgo'] === 'SHA' ? 'selected' : '') . ">SHA</option>
-    <option value='SHA-224' " . ($device['authalgo'] === 'SHA-224' ? 'selected' : '') . ($snmpv3_sha2 ? '' : ' disabled') . ">SHA-224</option>
-    <option value='SHA-256' " . ($device['authalgo'] === 'SHA-256' ? 'selected' : '') . ($snmpv3_sha2 ? '' : ' disabled') . ">SHA-256</option>
-    <option value='SHA-384' " . ($device['authalgo'] === 'SHA-384' ? 'selected' : '') . ($snmpv3_sha2 ? '' : ' disabled') . ">SHA-384</option>
-    <option value='SHA-512' " . ($device['authalgo'] === 'SHA-512' ? 'selected' : '') . ($snmpv3_sha2 ? '' : ' disabled') . '>SHA-512</option>
-    </select>
-    ';
-if (! $snmpv3_sha2) {
+    <select id='authalgo' name='authalgo' class='form-control'>";
+foreach (\LibreNMS\SNMPCapabilities::authAlgorithms() as $algo => $enabled) {
+    echo "<option value='$algo' " . ($device['authalgo'] === $algo ? 'selected' : '') . ($enabled ? '' : ' disabled') . ">$algo</option>\n";
+}
+echo '</select>';
+
+if (! \LibreNMS\SNMPCapabilities::supportsSHA2()) {
     echo '<label class="text-left"><small>Some options are disabled. <a href="https://docs.librenms.org/Support/FAQ/#optional-requirements-for-snmpv3-sha2-auth">Read more here</a></small></label>';
 }
-    echo "
+echo "
     </div>
     </div>
     <div class='form-group'>
@@ -381,15 +374,14 @@ if (! $snmpv3_sha2) {
     <div class='form-group'>
     <label for='cryptoalgo' class='col-sm-2 control-label'>Crypto Algorithm</label>
     <div class='col-sm-4'>
-    <select id='cryptoalgo' name='cryptoalgo' class='form-control'>
-    <option value='AES' " . ($device['cryptoalgo'] === 'AES' ? 'selected' : '') . ">AES</option>
-    <option value='AES-192' " . ($device['cryptoalgo'] === 'AES-192' ? 'selected' : '') . ($snmpv3_aes256 ? '' : ' disabled') . ">AES-192</option>
-    <option value='AES-256' " . ($device['cryptoalgo'] === 'AES-256' ? 'selected' : '') . ($snmpv3_aes256 ? '' : ' disabled') . ">AES-256</option>
-    <option value='AES-256-C' " . ($device['cryptoalgo'] === 'AES-256-C' ? 'selected' : '') . ($snmpv3_aes256 ? '' : ' disabled') . ">AES-256 Cisco</option>
-    <option value='DES' " . ($device['cryptoalgo'] === 'DES' ? 'selected' : '') . '>DES</option>
-    </select>
+    <select id='cryptoalgo' name='cryptoalgo' class='form-control'>";
+
+foreach (\LibreNMS\SNMPCapabilities::cryptoAlgoritms() as $algo => $enabled) {
+    echo "<option value='$algo' " . ($device['cryptoalgo'] === $algo ? 'selected' : '') . ($enabled ? '' : ' disabled') . ">$algo</option>\n";
+}
+echo '</select>
     ';
-if (! $snmpv3_aes256) {
+if (! \LibreNMS\SNMPCapabilities::supportsAES256()) {
     echo '<label class="text-left"><small>Some options are disabled. <a href="https://docs.librenms.org/Support/FAQ/#optional-requirements-for-snmpv3-sha2-auth">Read more here</a></small></label>';
 }
     echo '
