@@ -50,15 +50,16 @@ if (isset($agent_data) && isset($agent_data['app'][$name])) {
     } catch (JsonAppParsingFailedException $e) {
         $legacy = $e->getOutput();
     } catch (JsonAppException $e) {
-        echo PHP_EOL . $name . ':' .$e->getCode().':'. $e->getMessage() . PHP_EOL;
-        update_application($app, $e->getCode().':'.$e->getMessage(), []); // Set empty metrics and error message
+        echo PHP_EOL . $name . ':' . $e->getCode() . ':' . $e->getMessage() . PHP_EOL;
+        update_application($app, $e->getCode() . ':' . $e->getMessage(), []); // Set empty metrics and error message
+
         return;
     }
 }
 
 if (isset($legacy)) {
     // Legacy script, build compatible array
-    list(
+    [
         $powerdns['corrupt-packets'],
         $powerdns['deferred-cache-inserts'],
         $powerdns['deferred-cache-lookup'],
@@ -81,7 +82,7 @@ if (isset($legacy)) {
         $powerdns['udp4-queries'],
         $powerdns['udp6-answers'],
         $powerdns['udp6-queries'],
-        ) = explode("\n", $legacy);
+        ] = explode("\n", $legacy);
 }
 
 d_echo($powerdns);
