@@ -82,7 +82,7 @@ $rrd_def = RrdDefinition::make()
 $fields = [
     'charge' => $charge,
     'battery_low' => $battery_low,
-    'time_remaining' => $remaining / 60,
+    'time_remaining' => (int) $remaining / 60,
     'battery_voltage' => $bat_volt,
     'battery_nominal' => $bat_nom,
     'line_nominal' => $line_nom,
