@@ -1,5 +1,11 @@
 <?php
 
+use App\Models\Device;
+use Illuminate\Support\Facades\Artisan;
+use LibreNMS\Exceptions\HostUnreachableException;
+use LibreNMS\Util\Debug;
+use Symfony\Component\Process\Process;
+
 /*
 |--------------------------------------------------------------------------
 | Console Routes
@@ -11,11 +17,6 @@
 |
 */
 
-use App\Models\Device;
-use LibreNMS\Exceptions\HostUnreachableException;
-use LibreNMS\Util\Debug;
-use Symfony\Component\Process\Process;
-
 Artisan::command('device:rename
     {old hostname : ' . __('The existing hostname, IP, or device id') . '}
     {new hostname : ' . __('The new hostname or IP') . '}
@@ -42,8 +43,8 @@ Artisan::command('device:add
     {--r|port=161 : ' . __('SNMP transport port') . '}
     {--u|security-name=root : ' . __('SNMPv3 security username') . '}
     {--A|auth-password= : ' . __('SNMPv3 authentication password') . '}
-    {--a|auth-protocol=md5 : ' . __('SNMPv3 authentication protocol') . ' [md5, sha, sha-512, sha-384, sha-256, sha-224]}
-    {--x|privacy-protocol=aes : ' . __('SNMPv3 privacy protocol') . ' [des, aes]}
+    {--a|auth-protocol=md5 : ' . __('SNMPv3 authentication protocol') . ' [' . implode(', ', \LibreNMS\SNMPCapabilities::supportedAuthAlgorithms()) . ']}
+    {--x|privacy-protocol=aes : ' . __('SNMPv3 privacy protocol') . ' [' . implode(', ', \LibreNMS\SNMPCapabilities::supportedCryptoAlgorithms()) . ']}
     {--X|privacy-password= : ' . __('SNMPv3 privacy password') . '}
     {--P|ping-only : ' . __('Add a ping only device') . '}
     {--o|os=ping : ' . __('Ping only: specify OS') . '}
@@ -60,11 +61,11 @@ Artisan::command('device:add
         $this->error(__('Invalid SNMP transport'));
     }
 
-    if (! in_array($this->option('auth-protocol'), ['md5', 'sha', 'sha-512', 'sha-384', 'sha-256', 'sha-224'])) {
+    if (! in_array($this->option('auth-protocol'), \LibreNMS\SNMPCapabilities::supportedAuthAlgorithms())) {
         $this->error(__('Invalid authentication protocol'));
     }
 
-    if (! in_array($this->option('privacy-protocol'), ['des', 'aes'])) {
+    if (! in_array($this->option('privacy-protocol'), \LibreNMS\SNMPCapabilities::supportedCryptoAlgorithms())) {
         $this->error(__('Invalid privacy protocol'));
     }
 
